==> apple_pay_verification-1.0.0.zip: apple_pay_verification/src/Controller/ApplePayVerificationController.php <==
<?php

namespace Drupal\apple_pay_verification\Controller;

use Drupal\Core\Cache\CacheableResponse;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\file\FileInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Apple Pay Verification routes.
 */
class ApplePayVerificationController extends ControllerBase {

  /**
   * @var ConfigFactoryInterface
   *
   * The configuration factory.
   */
  protected $configFactory;

  /**
   * @var EntityTypeManagerInterface
   * The entity type manager service.
   */
  protected $entityTypeManager;

  /**
   * @param ConfigFactoryInterface $configFactory
   *   The configuration factory.
   */
  public function __construct(ConfigFactoryInterface $configFactory, EntityTypeManagerInterface $entityTypeManager) {
    $this->configFactory = $configFactory;
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
    );
  }

  /**
   * Builds the response.
   */
  public function __invoke() {
    $fileId = $this->configFactory->get('apple_pay_verification.settings')->get('verification_file');
    $fileId = reset($fileId);
    /** @var FileInterface $file */
    $file = $this->entityTypeManager->getStorage('file')->load($fileId);

    $response = new CacheableResponse(file_get_contents($file->getFileUri()));
    return $response;
  }

}

==> apple_pay_verification-1.0.2.zip: apple_pay_verification/src/Controller/ApplePayVerificationController.php <==
<?php

namespace Drupal\apple_pay_verification\Controller;

use Drupal\Core\Cache\CacheableResponse;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Apple Pay Verification routes.
 */
final class ApplePayVerificationController extends ControllerBase {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * ApplePayVerificationController constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The configuration factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager service.
   */
  public function __construct(ConfigFactoryInterface $configFactory, EntityTypeManagerInterface $entityTypeManager) {
    $this->configFactory = $configFactory;
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
    );
  }

  /**
   * Builds the response.
   */
  public function __invoke() {
    $fileId = $this->configFactory->get('apple_pay_verification.settings')->get('verification_file');
    $fileId = reset($fileId);
    /** @var \Drupal\file\FileInterface $file */
    $file = $this->entityTypeManager->getStorage('file')->load($fileId);

    $response = new CacheableResponse(file_get_contents($file->getFileUri()));
    $response->headers->set('Content-Type', 'text/plain');
    return $response;
  }

}
